@@ -312,7 +312,7 @@ class TestVariable(DaskTestCase):
     def test_tokenize_duck_dask_array(self):
         import pint
 
-        unit_registry = pint.UnitRegistry()
+        unit_registry: pint.UnitRegistry = pint.UnitRegistry()
 
         q = unit_registry.Quantity(self.data, "meter")
         variable = xr.Variable(("x", "y"), q)
@@ -471,7 +471,16 @@ class TestDataArrayAndDataset(DaskTestCase):
         assert isinstance(out["d"].data, dask.array.Array)
         assert isinstance(out["c"].data, dask.array.Array)
 
-        out = xr.concat([ds1, ds2, ds3], dim="n", data_vars=[], coords=[])
+        with xr.set_options(use_new_combine_kwarg_defaults=True):
+            out = xr.concat([ds1, ds2, ds3], dim="n", data_vars=[], coords=[])
+            # no extra kernel calls
+            assert kernel_call_count == 6
+            assert isinstance(out["d"].data, dask.array.Array)
+            assert isinstance(out["c"].data, dask.array.Array)
+
+        out = xr.concat(
+            [ds1, ds2, ds3], dim="n", data_vars=[], coords=[], compat="equals"
+        )
         # variables are loaded once as we are validating that they're identical
         assert kernel_call_count == 12
         assert isinstance(out["d"].data, np.ndarray)
@@ -791,7 +800,7 @@ class TestDataArrayAndDataset(DaskTestCase):
     def test_tokenize_duck_dask_array(self):
         import pint
 
-        unit_registry = pint.UnitRegistry()
+        unit_registry: pint.UnitRegistry = pint.UnitRegistry()
 
         q = unit_registry.Quantity(self.data, unit_registry.meter)
         data_array = xr.DataArray(
@@ -1161,6 +1170,21 @@ def test_auto_chunk_da(obj):
     assert actual.chunks == expected.chunks
 
 
+def test_auto_chunk_da_cftime():
+    yrs = np.arange(2000, 2120)
+    cftime_dates = xr.date_range(
+        start=f"{yrs[0]}-01-01", end=f"{yrs[-1]}-12-31", freq="1YE", use_cftime=True
+    )
+    yr_array = np.tile(cftime_dates.values, (10, 1))
+    da = xr.DataArray(
+        yr_array, dims=["x", "t"], coords={"x": np.arange(10), "t": cftime_dates}
+    ).chunk({"x": 4, "t": 5})
+    actual = da.chunk("auto").data
+    expected = da.data.rechunk({0: 10, 1: 120})
+    np.testing.assert_array_equal(actual, expected)
+    assert actual.chunks == expected.chunks
+
+
 def test_map_blocks_error(map_da, map_ds):
     def bad_func(darray):
         return (darray * darray.x + 5 * darray.y)[:1, :1]
